# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/dialogflow_v2beta1/proto/audio_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/dialogflow_v2beta1/proto/audio_config.proto",
    package="google.cloud.dialogflow.v2beta1",
    syntax="proto3",
    serialized_options=b"\n#com.google.cloud.dialogflow.v2beta1B\020AudioConfigProtoP\001ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\370\001\001\242\002\002DF\252\002\037Google.Cloud.Dialogflow.V2beta1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n8google/cloud/dialogflow_v2beta1/proto/audio_config.proto\x12\x1fgoogle.cloud.dialogflow.v2beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto"/\n\rSpeechContext\x12\x0f\n\x07phrases\x18\x01 \x03(\t\x12\r\n\x05\x62oost\x18\x02 \x01(\x02"\x92\x01\n\x0eSpeechWordInfo\x12\x0c\n\x04word\x18\x03 \x01(\t\x12/\n\x0cstart_offset\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\nend_offset\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nconfidence\x18\x04 \x01(\x02"\xfe\x02\n\x10InputAudioConfig\x12\x46\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32..google.cloud.dialogflow.v2beta1.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x05\x12\x15\n\rlanguage_code\x18\x03 \x01(\t\x12\x18\n\x10\x65nable_word_info\x18\r \x01(\x08\x12\x18\n\x0cphrase_hints\x18\x04 \x03(\tB\x02\x18\x01\x12G\n\x0fspeech_contexts\x18\x0b \x03(\x0b\x32..google.cloud.dialogflow.v2beta1.SpeechContext\x12\r\n\x05model\x18\x07 \x01(\t\x12J\n\rmodel_variant\x18\n \x01(\x0e\x32\x33.google.cloud.dialogflow.v2beta1.SpeechModelVariant\x12\x18\n\x10single_utterance\x18\x08 \x01(\x08"k\n\x14VoiceSelectionParams\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x0bssml_gender\x18\x02 \x01(\x0e\x32\x30.google.cloud.dialogflow.v2beta1.SsmlVoiceGender"\xb8\x01\n\x16SynthesizeSpeechConfig\x12\x15\n\rspeaking_rate\x18\x01 \x01(\x01\x12\r\n\x05pitch\x18\x02 \x01(\x01\x12\x16\n\x0evolume_gain_db\x18\x03 \x01(\x01\x12\x1a\n\x12\x65\x66\x66\x65\x63ts_profile_id\x18\x05 \x03(\t\x12\x44\n\x05voice\x18\x04 \x01(\x0b\x32\x35.google.cloud.dialogflow.v2beta1.VoiceSelectionParams"\xdc\x01\n\x11OutputAudioConfig\x12Q\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32\x34.google.cloud.dialogflow.v2beta1.OutputAudioEncodingB\x03\xe0\x41\x02\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x05\x12Y\n\x18synthesize_speech_config\x18\x03 \x01(\x0b\x32\x37.google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig*\xfb\x01\n\rAudioEncoding\x12\x1e\n\x1a\x41UDIO_ENCODING_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x41UDIO_ENCODING_LINEAR_16\x10\x01\x12\x17\n\x13\x41UDIO_ENCODING_FLAC\x10\x02\x12\x18\n\x14\x41UDIO_ENCODING_MULAW\x10\x03\x12\x16\n\x12\x41UDIO_ENCODING_AMR\x10\x04\x12\x19\n\x15\x41UDIO_ENCODING_AMR_WB\x10\x05\x12\x1b\n\x17\x41UDIO_ENCODING_OGG_OPUS\x10\x06\x12)\n%AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE\x10\x07*v\n\x12SpeechModelVariant\x12$\n SPEECH_MODEL_VARIANT_UNSPECIFIED\x10\x00\x12\x16\n\x12USE_BEST_AVAILABLE\x10\x01\x12\x10\n\x0cUSE_STANDARD\x10\x02\x12\x10\n\x0cUSE_ENHANCED\x10\x03*\x8d\x01\n\x0fSsmlVoiceGender\x12!\n\x1dSSML_VOICE_GENDER_UNSPECIFIED\x10\x00\x12\x1a\n\x16SSML_VOICE_GENDER_MALE\x10\x01\x12\x1c\n\x18SSML_VOICE_GENDER_FEMALE\x10\x02\x12\x1d\n\x19SSML_VOICE_GENDER_NEUTRAL\x10\x03*\xa4\x01\n\x13OutputAudioEncoding\x12%\n!OUTPUT_AUDIO_ENCODING_UNSPECIFIED\x10\x00\x12#\n\x1fOUTPUT_AUDIO_ENCODING_LINEAR_16\x10\x01\x12\x1d\n\x19OUTPUT_AUDIO_ENCODING_MP3\x10\x02\x12"\n\x1eOUTPUT_AUDIO_ENCODING_OGG_OPUS\x10\x03\x42\xae\x01\n#com.google.cloud.dialogflow.v2beta1B\x10\x41udioConfigProtoP\x01ZIgoogle.golang.org/genproto/googleapis/cloud/dialogflow/v2beta1;dialogflow\xf8\x01\x01\xa2\x02\x02\x44\x46\xaa\x02\x1fGoogle.Cloud.Dialogflow.V2beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)

_AUDIOENCODING = _descriptor.EnumDescriptor(
    name="AudioEncoding",
    full_name="google.cloud.dialogflow.v2beta1.AudioEncoding",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="AUDIO_ENCODING_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUDIO_ENCODING_LINEAR_16",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUDIO_ENCODING_FLAC",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUDIO_ENCODING_MULAW",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUDIO_ENCODING_AMR",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUDIO_ENCODING_AMR_WB",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUDIO_ENCODING_OGG_OPUS",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE",
            index=7,
            number=7,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1352,
    serialized_end=1603,
)
_sym_db.RegisterEnumDescriptor(_AUDIOENCODING)

AudioEncoding = enum_type_wrapper.EnumTypeWrapper(_AUDIOENCODING)
_SPEECHMODELVARIANT = _descriptor.EnumDescriptor(
    name="SpeechModelVariant",
    full_name="google.cloud.dialogflow.v2beta1.SpeechModelVariant",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SPEECH_MODEL_VARIANT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="USE_BEST_AVAILABLE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="USE_STANDARD",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="USE_ENHANCED",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1605,
    serialized_end=1723,
)
_sym_db.RegisterEnumDescriptor(_SPEECHMODELVARIANT)

SpeechModelVariant = enum_type_wrapper.EnumTypeWrapper(_SPEECHMODELVARIANT)
_SSMLVOICEGENDER = _descriptor.EnumDescriptor(
    name="SsmlVoiceGender",
    full_name="google.cloud.dialogflow.v2beta1.SsmlVoiceGender",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SSML_VOICE_GENDER_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SSML_VOICE_GENDER_MALE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SSML_VOICE_GENDER_FEMALE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SSML_VOICE_GENDER_NEUTRAL",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1726,
    serialized_end=1867,
)
_sym_db.RegisterEnumDescriptor(_SSMLVOICEGENDER)

SsmlVoiceGender = enum_type_wrapper.EnumTypeWrapper(_SSMLVOICEGENDER)
_OUTPUTAUDIOENCODING = _descriptor.EnumDescriptor(
    name="OutputAudioEncoding",
    full_name="google.cloud.dialogflow.v2beta1.OutputAudioEncoding",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="OUTPUT_AUDIO_ENCODING_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="OUTPUT_AUDIO_ENCODING_LINEAR_16",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="OUTPUT_AUDIO_ENCODING_MP3",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="OUTPUT_AUDIO_ENCODING_OGG_OPUS",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1870,
    serialized_end=2034,
)
_sym_db.RegisterEnumDescriptor(_OUTPUTAUDIOENCODING)

OutputAudioEncoding = enum_type_wrapper.EnumTypeWrapper(_OUTPUTAUDIOENCODING)
AUDIO_ENCODING_UNSPECIFIED = 0
AUDIO_ENCODING_LINEAR_16 = 1
AUDIO_ENCODING_FLAC = 2
AUDIO_ENCODING_MULAW = 3
AUDIO_ENCODING_AMR = 4
AUDIO_ENCODING_AMR_WB = 5
AUDIO_ENCODING_OGG_OPUS = 6
AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE = 7
SPEECH_MODEL_VARIANT_UNSPECIFIED = 0
USE_BEST_AVAILABLE = 1
USE_STANDARD = 2
USE_ENHANCED = 3
SSML_VOICE_GENDER_UNSPECIFIED = 0
SSML_VOICE_GENDER_MALE = 1
SSML_VOICE_GENDER_FEMALE = 2
SSML_VOICE_GENDER_NEUTRAL = 3
OUTPUT_AUDIO_ENCODING_UNSPECIFIED = 0
OUTPUT_AUDIO_ENCODING_LINEAR_16 = 1
OUTPUT_AUDIO_ENCODING_MP3 = 2
OUTPUT_AUDIO_ENCODING_OGG_OPUS = 3


_SPEECHCONTEXT = _descriptor.Descriptor(
    name="SpeechContext",
    full_name="google.cloud.dialogflow.v2beta1.SpeechContext",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="phrases",
            full_name="google.cloud.dialogflow.v2beta1.SpeechContext.phrases",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="boost",
            full_name="google.cloud.dialogflow.v2beta1.SpeechContext.boost",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=249,
    serialized_end=296,
)


_SPEECHWORDINFO = _descriptor.Descriptor(
    name="SpeechWordInfo",
    full_name="google.cloud.dialogflow.v2beta1.SpeechWordInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="word",
            full_name="google.cloud.dialogflow.v2beta1.SpeechWordInfo.word",
            index=0,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="start_offset",
            full_name="google.cloud.dialogflow.v2beta1.SpeechWordInfo.start_offset",
            index=1,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_offset",
            full_name="google.cloud.dialogflow.v2beta1.SpeechWordInfo.end_offset",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="confidence",
            full_name="google.cloud.dialogflow.v2beta1.SpeechWordInfo.confidence",
            index=3,
            number=4,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=299,
    serialized_end=445,
)


_INPUTAUDIOCONFIG = _descriptor.Descriptor(
    name="InputAudioConfig",
    full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="audio_encoding",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.audio_encoding",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sample_rate_hertz",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.sample_rate_hertz",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="language_code",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.language_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="enable_word_info",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.enable_word_info",
            index=3,
            number=13,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="phrase_hints",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.phrase_hints",
            index=4,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\030\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="speech_contexts",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.speech_contexts",
            index=5,
            number=11,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="model",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.model",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="model_variant",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.model_variant",
            index=7,
            number=10,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="single_utterance",
            full_name="google.cloud.dialogflow.v2beta1.InputAudioConfig.single_utterance",
            index=8,
            number=8,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=448,
    serialized_end=830,
)


_VOICESELECTIONPARAMS = _descriptor.Descriptor(
    name="VoiceSelectionParams",
    full_name="google.cloud.dialogflow.v2beta1.VoiceSelectionParams",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.dialogflow.v2beta1.VoiceSelectionParams.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ssml_gender",
            full_name="google.cloud.dialogflow.v2beta1.VoiceSelectionParams.ssml_gender",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=832,
    serialized_end=939,
)


_SYNTHESIZESPEECHCONFIG = _descriptor.Descriptor(
    name="SynthesizeSpeechConfig",
    full_name="google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="speaking_rate",
            full_name="google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.speaking_rate",
            index=0,
            number=1,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="pitch",
            full_name="google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.pitch",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="volume_gain_db",
            full_name="google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.volume_gain_db",
            index=2,
            number=3,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="effects_profile_id",
            full_name="google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.effects_profile_id",
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="voice",
            full_name="google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig.voice",
            index=4,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=942,
    serialized_end=1126,
)


_OUTPUTAUDIOCONFIG = _descriptor.Descriptor(
    name="OutputAudioConfig",
    full_name="google.cloud.dialogflow.v2beta1.OutputAudioConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="audio_encoding",
            full_name="google.cloud.dialogflow.v2beta1.OutputAudioConfig.audio_encoding",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sample_rate_hertz",
            full_name="google.cloud.dialogflow.v2beta1.OutputAudioConfig.sample_rate_hertz",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="synthesize_speech_config",
            full_name="google.cloud.dialogflow.v2beta1.OutputAudioConfig.synthesize_speech_config",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1129,
    serialized_end=1349,
)

_SPEECHWORDINFO.fields_by_name[
    "start_offset"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SPEECHWORDINFO.fields_by_name[
    "end_offset"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_INPUTAUDIOCONFIG.fields_by_name["audio_encoding"].enum_type = _AUDIOENCODING
_INPUTAUDIOCONFIG.fields_by_name["speech_contexts"].message_type = _SPEECHCONTEXT
_INPUTAUDIOCONFIG.fields_by_name["model_variant"].enum_type = _SPEECHMODELVARIANT
_VOICESELECTIONPARAMS.fields_by_name["ssml_gender"].enum_type = _SSMLVOICEGENDER
_SYNTHESIZESPEECHCONFIG.fields_by_name["voice"].message_type = _VOICESELECTIONPARAMS
_OUTPUTAUDIOCONFIG.fields_by_name["audio_encoding"].enum_type = _OUTPUTAUDIOENCODING
_OUTPUTAUDIOCONFIG.fields_by_name[
    "synthesize_speech_config"
].message_type = _SYNTHESIZESPEECHCONFIG
DESCRIPTOR.message_types_by_name["SpeechContext"] = _SPEECHCONTEXT
DESCRIPTOR.message_types_by_name["SpeechWordInfo"] = _SPEECHWORDINFO
DESCRIPTOR.message_types_by_name["InputAudioConfig"] = _INPUTAUDIOCONFIG
DESCRIPTOR.message_types_by_name["VoiceSelectionParams"] = _VOICESELECTIONPARAMS
DESCRIPTOR.message_types_by_name["SynthesizeSpeechConfig"] = _SYNTHESIZESPEECHCONFIG
DESCRIPTOR.message_types_by_name["OutputAudioConfig"] = _OUTPUTAUDIOCONFIG
DESCRIPTOR.enum_types_by_name["AudioEncoding"] = _AUDIOENCODING
DESCRIPTOR.enum_types_by_name["SpeechModelVariant"] = _SPEECHMODELVARIANT
DESCRIPTOR.enum_types_by_name["SsmlVoiceGender"] = _SSMLVOICEGENDER
DESCRIPTOR.enum_types_by_name["OutputAudioEncoding"] = _OUTPUTAUDIOENCODING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpeechContext = _reflection.GeneratedProtocolMessageType(
    "SpeechContext",
    (_message.Message,),
    {
        "DESCRIPTOR": _SPEECHCONTEXT,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.audio_config_pb2",
        "__doc__": """Hints for the speech recognizer to help with recognition in a specific
  conversation state.
  
  Attributes:
      phrases:
          Optional. A list of strings containing words and phrases that
          the speech recognizer should recognize with higher likelihood.
          This list can be used to:  -  improve accuracy for words and
          phrases you expect the user to say,    e.g. typical commands
          for your Dialogflow agent -  add additional words to the
          speech recognizer vocabulary -  …  See the `Cloud Speech
          documentation <https://cloud.google.com/speech-to-
          text/quotas>`__ for usage limits.
      boost:
          Optional. Boost for this context compared to other contexts:
          -  If the boost is positive, Dialogflow will increase the
          probability    that the phrases in this context are recognized
          over similar sounding    phrases. -  If the boost is
          unspecified or non-positive, Dialogflow will not    apply any
          boost.  Dialogflow recommends that you use boosts in the range
          (0, 20] and that you find a value that fits your use case with
          binary search.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.SpeechContext)
    },
)
_sym_db.RegisterMessage(SpeechContext)

SpeechWordInfo = _reflection.GeneratedProtocolMessageType(
    "SpeechWordInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _SPEECHWORDINFO,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.audio_config_pb2",
        "__doc__": """Information for a word recognized by the speech recognizer.
  
  Attributes:
      word:
          The word this info is for.
      start_offset:
          Time offset relative to the beginning of the audio that
          corresponds to the start of the spoken word. This is an
          experimental feature and the accuracy of the time offset can
          vary.
      end_offset:
          Time offset relative to the beginning of the audio that
          corresponds to the end of the spoken word. This is an
          experimental feature and the accuracy of the time offset can
          vary.
      confidence:
          The Speech confidence between 0.0 and 1.0 for this word. A
          higher number indicates an estimated greater likelihood that
          the recognized word is correct. The default of 0.0 is a
          sentinel value indicating that confidence was not set.  This
          field is not guaranteed to be fully stable over time for the
          same audio input. Users should also not rely on it to always
          be provided.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.SpeechWordInfo)
    },
)
_sym_db.RegisterMessage(SpeechWordInfo)

InputAudioConfig = _reflection.GeneratedProtocolMessageType(
    "InputAudioConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _INPUTAUDIOCONFIG,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.audio_config_pb2",
        "__doc__": """Instructs the speech recognizer on how to process the audio content.
  
  Attributes:
      audio_encoding:
          Required. Audio encoding of the audio content to process.
      sample_rate_hertz:
          Required. Sample rate (in Hertz) of the audio content sent in
          the query. Refer to `Cloud Speech API documentation
          <https://cloud.google.com/speech-to-text/docs/basics>`__ for
          more details.
      language_code:
          Required. The language of the supplied audio. Dialogflow does
          not do translations. See `Language Support <https://cloud.goog
          le.com/dialogflow/docs/reference/language>`__ for a list of
          the currently supported language codes. Note that queries in
          the same session do not necessarily need to specify the same
          language.
      enable_word_info:
          If ``true``, Dialogflow returns [SpeechWordInfo][google.cloud.
          dialogflow.v2beta1.SpeechWordInfo] in [StreamingRecognitionRes
          ult][google.cloud.dialogflow.v2beta1.StreamingRecognitionResul
          t] with information about the recognized speech words,
          e.g. start and end time offsets. If false or unspecified,
          Speech doesn’t return any word-level information.
      phrase_hints:
          A list of strings containing words and phrases that the speech
          recognizer should recognize with higher likelihood.  See `the
          Cloud Speech documentation <https://cloud.google.com/speech-
          to-text/docs/basics#phrase-hints>`__ for more details.  This
          field is deprecated. Please use `speech_contexts`
          instead. If you specify both `phrase_hints` and
          `speech_contexts`, Dialogflow will treat the
          `phrase_hints` as a single additional `SpeechContext`.
      speech_contexts:
          Context information to assist speech recognition.  See `the
          Cloud Speech documentation <https://cloud.google.com/speech-
          to-text/docs/basics#phrase-hints>`__ for more details.
      model:
          Which Speech model to select for the given request. Select the
          model best suited to your domain to get best results. If a
          model is not explicitly specified, then we auto-select a model
          based on the parameters in the InputAudioConfig. If enhanced
          speech model is enabled for the agent and an enhanced version
          of the specified model for the language does not exist, then
          the speech is recognized using the standard version of the
          specified model. Refer to `Cloud Speech API documentation
          <https://cloud.google.com/speech-to-text/docs/basics#select-
          model>`__ for more details.
      model_variant:
          Which variant of the [Speech
          model][google.cloud.dialogflow.v2beta1.InputAudioConfig.model]
          to use.
      single_utterance:
          If ``false`` (default), recognition does not cease until the
          client closes the stream. If ``true``, the recognizer will
          detect a single spoken utterance in input audio. Recognition
          ceases when it detects the audio’s voice has stopped or
          paused. In this case, once a detected intent is received, the
          client should close the stream and start a new request with a
          new stream as needed. Note: This setting is relevant only for
          streaming methods. Note: When specified,
          InputAudioConfig.single_utterance takes precedence over
          StreamingDetectIntentRequest.single_utterance.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.InputAudioConfig)
    },
)
_sym_db.RegisterMessage(InputAudioConfig)

VoiceSelectionParams = _reflection.GeneratedProtocolMessageType(
    "VoiceSelectionParams",
    (_message.Message,),
    {
        "DESCRIPTOR": _VOICESELECTIONPARAMS,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.audio_config_pb2",
        "__doc__": """Description of which voice to use for speech synthesis.
  
  Attributes:
      name:
          Optional. The name of the voice. If not set, the service will
          choose a voice based on the other parameters such as
          language_code and [ssml_gender][google.cloud.dialogflow.v2beta
          1.VoiceSelectionParams.ssml_gender].
      ssml_gender:
          Optional. The preferred gender of the voice. If not set, the
          service will choose a voice based on the other parameters such
          as language_code and [name][google.cloud.dialogflow.v2beta1.Vo
          iceSelectionParams.name]. Note that this is only a preference,
          not requirement. If a voice of the appropriate gender is not
          available, the synthesizer should substitute a voice with a
          different gender rather than failing the request.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.VoiceSelectionParams)
    },
)
_sym_db.RegisterMessage(VoiceSelectionParams)

SynthesizeSpeechConfig = _reflection.GeneratedProtocolMessageType(
    "SynthesizeSpeechConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _SYNTHESIZESPEECHCONFIG,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.audio_config_pb2",
        "__doc__": """Configuration of how speech should be synthesized.
  
  Attributes:
      speaking_rate:
          Optional. Speaking rate/speed, in the range [0.25, 4.0]. 1.0
          is the normal native speed supported by the specific voice.
          2.0 is twice as fast, and 0.5 is half as fast. If unset(0.0),
          defaults to the native 1.0 speed. Any other values < 0.25 or >
          4.0 will return an error.
      pitch:
          Optional. Speaking pitch, in the range [-20.0, 20.0]. 20 means
          increase 20 semitones from the original pitch. -20 means
          decrease 20 semitones from the original pitch.
      volume_gain_db:
          Optional. Volume gain (in dB) of the normal native volume
          supported by the specific voice, in the range [-96.0, 16.0].
          If unset, or set to a value of 0.0 (dB), will play at normal
          native signal amplitude. A value of -6.0 (dB) will play at
          approximately half the amplitude of the normal native signal
          amplitude. A value of +6.0 (dB) will play at approximately
          twice the amplitude of the normal native signal amplitude. We
          strongly recommend not to exceed +10 (dB) as there’s usually
          no effective increase in loudness for any value greater than
          that.
      effects_profile_id:
          Optional. An identifier which selects ‘audio effects’ profiles
          that are applied on (post synthesized) text to speech. Effects
          are applied on top of each other in the order they are given.
      voice:
          Optional. The desired voice of the synthesized audio.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.SynthesizeSpeechConfig)
    },
)
_sym_db.RegisterMessage(SynthesizeSpeechConfig)

OutputAudioConfig = _reflection.GeneratedProtocolMessageType(
    "OutputAudioConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _OUTPUTAUDIOCONFIG,
        "__module__": "google.cloud.dialogflow_v2beta1.proto.audio_config_pb2",
        "__doc__": """Instructs the speech synthesizer how to generate the output audio
  content. If this audio config is supplied in a request, it overrides
  all existing text-to-speech settings applied to the agent.
  
  Attributes:
      audio_encoding:
          Required. Audio encoding of the synthesized audio content.
      sample_rate_hertz:
          The synthesis sample rate (in hertz) for this audio. If not
          provided, then the synthesizer will use the default sample
          rate based on the audio encoding. If this is different from
          the voice’s natural sample rate, then the synthesizer will
          honor this request by converting to the desired sample rate
          (which might result in worse audio quality).
      synthesize_speech_config:
          Configuration of how speech should be synthesized.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.dialogflow.v2beta1.OutputAudioConfig)
    },
)
_sym_db.RegisterMessage(OutputAudioConfig)


DESCRIPTOR._options = None
_INPUTAUDIOCONFIG.fields_by_name["phrase_hints"]._options = None
_OUTPUTAUDIOCONFIG.fields_by_name["audio_encoding"]._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

import dialogflow_v2beta1
from dialogflow_v2beta1.proto import session_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)

    def stream_stream(
        self, method, request_serializer=None, response_deserializer=None
    ):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestSessionsClient(object):
    def test_detect_intent(self):
        # Setup Expected Response
        response_id = "responseId1847552473"
        output_audio = b"24"
        expected_response = {"response_id": response_id, "output_audio": output_audio}
        expected_response = session_pb2.DetectIntentResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.SessionsClient()

        # Setup Request
        session = "session1984987798"
        query_input = {}

        response = client.detect_intent(session, query_input)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = session_pb2.DetectIntentRequest(
            session=session, query_input=query_input
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_detect_intent_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.SessionsClient()

        # Setup request
        session = "session1984987798"
        query_input = {}

        with pytest.raises(CustomException):
            client.detect_intent(session, query_input)

    def test_streaming_detect_intent(self):
        # Setup Expected Response
        response_id = "responseId1847552473"
        output_audio = b"24"
        expected_response = {"response_id": response_id, "output_audio": output_audio}
        expected_response = session_pb2.StreamingDetectIntentResponse(
            **expected_response
        )

        # Mock the API response
        channel = ChannelStub(responses=[iter([expected_response])])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.SessionsClient()

        # Setup Request
        session = "session1984987798"
        query_input = {}
        request = {"session": session, "query_input": query_input}
        request = session_pb2.StreamingDetectIntentRequest(**request)
        requests = [request]

        response = client.streaming_detect_intent(requests)
        resources = list(response)
        assert len(resources) == 1
        assert expected_response == resources[0]

        assert len(channel.requests) == 1
        actual_requests = channel.requests[0][1]
        assert len(actual_requests) == 1
        actual_request = list(actual_requests)[0]
        assert request == actual_request

    def test_streaming_detect_intent_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2beta1.SessionsClient()

        # Setup request
        session = "session1984987798"
        query_input = {}
        request = {"session": session, "query_input": query_input}

        request = session_pb2.StreamingDetectIntentRequest(**request)
        requests = [request]

        with pytest.raises(CustomException):
            client.streaming_detect_intent(requests)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

import dialogflow_v2
from dialogflow_v2.proto import session_entity_type_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestSessionEntityTypesClient(object):
    def test_list_session_entity_types(self):
        # Setup Expected Response
        next_page_token = ""
        session_entity_types_element = {}
        session_entity_types = [session_entity_types_element]
        expected_response = {
            "next_page_token": next_page_token,
            "session_entity_types": session_entity_types,
        }
        expected_response = session_entity_type_pb2.ListSessionEntityTypesResponse(
            **expected_response
        )

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup Request
        parent = "parent-995424086"

        paged_list_response = client.list_session_entity_types(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.session_entity_types[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = session_entity_type_pb2.ListSessionEntityTypesRequest(
            parent=parent
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_session_entity_types_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup request
        parent = "parent-995424086"

        paged_list_response = client.list_session_entity_types(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_get_session_entity_type(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        expected_response = {"name": name_2}
        expected_response = session_entity_type_pb2.SessionEntityType(
            **expected_response
        )

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup Request
        name = "name3373707"

        response = client.get_session_entity_type(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = session_entity_type_pb2.GetSessionEntityTypeRequest(
            name=name
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_session_entity_type_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup request
        name = "name3373707"

        with pytest.raises(CustomException):
            client.get_session_entity_type(name)

    def test_create_session_entity_type(self):
        # Setup Expected Response
        name = "name3373707"
        expected_response = {"name": name}
        expected_response = session_entity_type_pb2.SessionEntityType(
            **expected_response
        )

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup Request
        parent = "parent-995424086"
        session_entity_type = {}

        response = client.create_session_entity_type(parent, session_entity_type)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = session_entity_type_pb2.CreateSessionEntityTypeRequest(
            parent=parent, session_entity_type=session_entity_type
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_session_entity_type_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup request
        parent = "parent-995424086"
        session_entity_type = {}

        with pytest.raises(CustomException):
            client.create_session_entity_type(parent, session_entity_type)

    def test_update_session_entity_type(self):
        # Setup Expected Response
        name = "name3373707"
        expected_response = {"name": name}
        expected_response = session_entity_type_pb2.SessionEntityType(
            **expected_response
        )

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup Request
        session_entity_type = {}

        response = client.update_session_entity_type(session_entity_type)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = session_entity_type_pb2.UpdateSessionEntityTypeRequest(
            session_entity_type=session_entity_type
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_session_entity_type_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup request
        session_entity_type = {}

        with pytest.raises(CustomException):
            client.update_session_entity_type(session_entity_type)

    def test_delete_session_entity_type(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup Request
        name = "name3373707"

        client.delete_session_entity_type(name)

        assert len(channel.requests) == 1
        expected_request = session_entity_type_pb2.DeleteSessionEntityTypeRequest(
            name=name
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_session_entity_type_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.SessionEntityTypesClient()

        # Setup request
        name = "name3373707"

        with pytest.raises(CustomException):
            client.delete_session_entity_type(name)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

from google.rpc import status_pb2

import dialogflow_v2
from dialogflow_v2.proto import entity_type_pb2
from google.longrunning import operations_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestEntityTypesClient(object):
    def test_list_entity_types(self):
        # Setup Expected Response
        next_page_token = ""
        entity_types_element = {}
        entity_types = [entity_types_element]
        expected_response = {
            "next_page_token": next_page_token,
            "entity_types": entity_types,
        }
        expected_response = entity_type_pb2.ListEntityTypesResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.agent_path("[PROJECT]")

        paged_list_response = client.list_entity_types(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.entity_types[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.ListEntityTypesRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_entity_types_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup request
        parent = client.agent_path("[PROJECT]")

        paged_list_response = client.list_entity_types(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)

    def test_get_entity_type(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        display_name = "displayName1615086568"
        enable_fuzzy_extraction = True
        expected_response = {
            "name": name_2,
            "display_name": display_name,
            "enable_fuzzy_extraction": enable_fuzzy_extraction,
        }
        expected_response = entity_type_pb2.EntityType(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        name = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")

        response = client.get_entity_type(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.GetEntityTypeRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_entity_type_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup request
        name = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")

        with pytest.raises(CustomException):
            client.get_entity_type(name)

    def test_create_entity_type(self):
        # Setup Expected Response
        name = "name3373707"
        display_name = "displayName1615086568"
        enable_fuzzy_extraction = True
        expected_response = {
            "name": name,
            "display_name": display_name,
            "enable_fuzzy_extraction": enable_fuzzy_extraction,
        }
        expected_response = entity_type_pb2.EntityType(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.agent_path("[PROJECT]")
        entity_type = {}

        response = client.create_entity_type(parent, entity_type)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.CreateEntityTypeRequest(
            parent=parent, entity_type=entity_type
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_entity_type_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup request
        parent = client.agent_path("[PROJECT]")
        entity_type = {}

        with pytest.raises(CustomException):
            client.create_entity_type(parent, entity_type)

    def test_update_entity_type(self):
        # Setup Expected Response
        name = "name3373707"
        display_name = "displayName1615086568"
        enable_fuzzy_extraction = True
        expected_response = {
            "name": name,
            "display_name": display_name,
            "enable_fuzzy_extraction": enable_fuzzy_extraction,
        }
        expected_response = entity_type_pb2.EntityType(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        entity_type = {}

        response = client.update_entity_type(entity_type)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.UpdateEntityTypeRequest(
            entity_type=entity_type
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_entity_type_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup request
        entity_type = {}

        with pytest.raises(CustomException):
            client.update_entity_type(entity_type)

    def test_delete_entity_type(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        name = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")

        client.delete_entity_type(name)

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.DeleteEntityTypeRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_entity_type_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup request
        name = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")

        with pytest.raises(CustomException):
            client.delete_entity_type(name)

    def test_batch_update_entity_types(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = entity_type_pb2.BatchUpdateEntityTypesResponse(
            **expected_response
        )
        operation = operations_pb2.Operation(
            name="operations/test_batch_update_entity_types", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.agent_path("[PROJECT]")

        response = client.batch_update_entity_types(parent)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.BatchUpdateEntityTypesRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_update_entity_types_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_batch_update_entity_types_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.agent_path("[PROJECT]")

        response = client.batch_update_entity_types(parent)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_batch_delete_entity_types(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_batch_delete_entity_types", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.agent_path("[PROJECT]")
        entity_type_names = []

        response = client.batch_delete_entity_types(parent, entity_type_names)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.BatchDeleteEntityTypesRequest(
            parent=parent, entity_type_names=entity_type_names
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_delete_entity_types_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_batch_delete_entity_types_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.agent_path("[PROJECT]")
        entity_type_names = []

        response = client.batch_delete_entity_types(parent, entity_type_names)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_batch_create_entities(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_batch_create_entities", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
        entities = []

        response = client.batch_create_entities(parent, entities)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.BatchCreateEntitiesRequest(
            parent=parent, entities=entities
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_create_entities_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_batch_create_entities_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
        entities = []

        response = client.batch_create_entities(parent, entities)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_batch_update_entities(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_batch_update_entities", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
        entities = []

        response = client.batch_update_entities(parent, entities)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.BatchUpdateEntitiesRequest(
            parent=parent, entities=entities
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_update_entities_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_batch_update_entities_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
        entities = []

        response = client.batch_update_entities(parent, entities)
        exception = response.exception()
        assert exception.errors[0] == error

    def test_batch_delete_entities(self):
        # Setup Expected Response
        expected_response = {}
        expected_response = empty_pb2.Empty(**expected_response)
        operation = operations_pb2.Operation(
            name="operations/test_batch_delete_entities", done=True
        )
        operation.response.Pack(expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
        entity_values = []

        response = client.batch_delete_entities(parent, entity_values)
        result = response.result()
        assert expected_response == result

        assert len(channel.requests) == 1
        expected_request = entity_type_pb2.BatchDeleteEntitiesRequest(
            parent=parent, entity_values=entity_values
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_batch_delete_entities_exception(self):
        # Setup Response
        error = status_pb2.Status()
        operation = operations_pb2.Operation(
            name="operations/test_batch_delete_entities_exception", done=True
        )
        operation.error.CopyFrom(error)

        # Mock the API response
        channel = ChannelStub(responses=[operation])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = dialogflow_v2.EntityTypesClient()

        # Setup Request
        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
        entity_values = []

        response = client.batch_delete_entities(parent, entity_values)
        exception = response.exception()
        assert exception.errors[0] == error



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dialogflow_v2.proto import (
    environment_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_environment__pb2,
)


class EnvironmentsStub(object):
    """Service for managing [Environments][google.cloud.dialogflow.v2.Environment].
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListEnvironments = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Environments/ListEnvironments",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_environment__pb2.ListEnvironmentsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_environment__pb2.ListEnvironmentsResponse.FromString,
        )


class EnvironmentsServicer(object):
    """Service for managing [Environments][google.cloud.dialogflow.v2.Environment].
    """

    def ListEnvironments(self, request, context):
        """Returns the list of all non-draft environments of the specified agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_EnvironmentsServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ListEnvironments": grpc.unary_unary_rpc_method_handler(
            servicer.ListEnvironments,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_environment__pb2.ListEnvironmentsRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_environment__pb2.ListEnvironmentsResponse.SerializeToString,
        )
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.dialogflow.v2.Environments", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class Environments(object):
    """Service for managing [Environments][google.cloud.dialogflow.v2.Environment].
    """

    @staticmethod
    def ListEnvironments(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Environments/ListEnvironments",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_environment__pb2.ListEnvironmentsRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_environment__pb2.ListEnvironmentsResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import
import sys
import warnings

from dialogflow_v2beta1 import types
from dialogflow_v2beta1.gapic import agents_client
from dialogflow_v2beta1.gapic import contexts_client
from dialogflow_v2beta1.gapic import documents_client
from dialogflow_v2beta1.gapic import entity_types_client
from dialogflow_v2beta1.gapic import enums
from dialogflow_v2beta1.gapic import environments_client
from dialogflow_v2beta1.gapic import intents_client
from dialogflow_v2beta1.gapic import knowledge_bases_client
from dialogflow_v2beta1.gapic import session_entity_types_client
from dialogflow_v2beta1.gapic import sessions_client


if sys.version_info[:2] == (2, 7):
    message = (
        "A future version of this library will drop support for Python 2.7. "
        "More details about Python 2 support for Google Cloud Client Libraries "
        "can be found at https://cloud.google.com/python/docs/python2-sunset/"
    )
    warnings.warn(message, DeprecationWarning)


package_deprecation_message = (
    "The package 'dialogflow' has been renamed to 'google-cloud-dialogflow'. "
    "'dialogflow' will no longer be updated. "
    "For help upgrading to google-cloud-dialogflow>=2.0.0, "
    "see https://github.com/googleapis/python-dialogflow/blob/master/UPGRADING.md. "
    "\n\nAfter October 28, 2021, importing code from the latest release of 'dialogflow' "
    "will result in a RuntimeError. If you need to continue to use 'dialogflow' after this date, "
    "please pin to a specific version of 'dialogflow' (e.g., dialogflow==1.1.1). "
    "If you have questions, please file an issue: "
    "https://github.com/googleapis/python-dialogflow/issues."
)

warnings.warn(
    package_deprecation_message,
    DeprecationWarning
)
class EnvironmentsClient(environments_client.EnvironmentsClient):
    __doc__ = environments_client.EnvironmentsClient.__doc__
    enums = enums


class AgentsClient(agents_client.AgentsClient):
    __doc__ = agents_client.AgentsClient.__doc__
    enums = enums


class ContextsClient(contexts_client.ContextsClient):
    __doc__ = contexts_client.ContextsClient.__doc__
    enums = enums


class DocumentsClient(documents_client.DocumentsClient):
    __doc__ = documents_client.DocumentsClient.__doc__
    enums = enums


class EntityTypesClient(entity_types_client.EntityTypesClient):
    __doc__ = entity_types_client.EntityTypesClient.__doc__
    enums = enums


class IntentsClient(intents_client.IntentsClient):
    __doc__ = intents_client.IntentsClient.__doc__
    enums = enums


class KnowledgeBasesClient(knowledge_bases_client.KnowledgeBasesClient):
    __doc__ = knowledge_bases_client.KnowledgeBasesClient.__doc__
    enums = enums


class SessionEntityTypesClient(session_entity_types_client.SessionEntityTypesClient):
    __doc__ = session_entity_types_client.SessionEntityTypesClient.__doc__
    enums = enums


class SessionsClient(sessions_client.SessionsClient):
    __doc__ = sessions_client.SessionsClient.__doc__
    enums = enums


__all__ = (
    "enums",
    "types",
    "EnvironmentsClient",
    "AgentsClient",
    "ContextsClient",
    "DocumentsClient",
    "EntityTypesClient",
    "IntentsClient",
    "KnowledgeBasesClient",
    "SessionEntityTypesClient",
    "SessionsClient",
)



# -*- coding: utf-8 -*-
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dialogflow_v2.proto import (
    intent_pb2 as google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class IntentsStub(object):
    """Service for managing [Intents][google.cloud.dialogflow.v2.Intent].
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListIntents = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Intents/ListIntents",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.ListIntentsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.ListIntentsResponse.FromString,
        )
        self.GetIntent = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Intents/GetIntent",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.GetIntentRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.FromString,
        )
        self.CreateIntent = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Intents/CreateIntent",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.CreateIntentRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.FromString,
        )
        self.UpdateIntent = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Intents/UpdateIntent",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.UpdateIntentRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.FromString,
        )
        self.DeleteIntent = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Intents/DeleteIntent",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.DeleteIntentRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.BatchUpdateIntents = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Intents/BatchUpdateIntents",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.BatchUpdateIntentsRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.BatchDeleteIntents = channel.unary_unary(
            "/google.cloud.dialogflow.v2.Intents/BatchDeleteIntents",
            request_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.BatchDeleteIntentsRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )


class IntentsServicer(object):
    """Service for managing [Intents][google.cloud.dialogflow.v2.Intent].
    """

    def ListIntents(self, request, context):
        """Returns the list of all intents in the specified agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetIntent(self, request, context):
        """Retrieves the specified intent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateIntent(self, request, context):
        """Creates an intent in the specified agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateIntent(self, request, context):
        """Updates the specified intent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteIntent(self, request, context):
        """Deletes the specified intent and its direct or indirect followup intents.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchUpdateIntents(self, request, context):
        """Updates/Creates multiple intents in the specified agent.

        Operation <response: [BatchUpdateIntentsResponse][google.cloud.dialogflow.v2.BatchUpdateIntentsResponse]>
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchDeleteIntents(self, request, context):
        """Deletes intents in the specified agent.

        Operation <response: [google.protobuf.Empty][google.protobuf.Empty]>
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_IntentsServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ListIntents": grpc.unary_unary_rpc_method_handler(
            servicer.ListIntents,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.ListIntentsRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.ListIntentsResponse.SerializeToString,
        ),
        "GetIntent": grpc.unary_unary_rpc_method_handler(
            servicer.GetIntent,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.GetIntentRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.SerializeToString,
        ),
        "CreateIntent": grpc.unary_unary_rpc_method_handler(
            servicer.CreateIntent,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.CreateIntentRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.SerializeToString,
        ),
        "UpdateIntent": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateIntent,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.UpdateIntentRequest.FromString,
            response_serializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.SerializeToString,
        ),
        "DeleteIntent": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteIntent,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.DeleteIntentRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "BatchUpdateIntents": grpc.unary_unary_rpc_method_handler(
            servicer.BatchUpdateIntents,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.BatchUpdateIntentsRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "BatchDeleteIntents": grpc.unary_unary_rpc_method_handler(
            servicer.BatchDeleteIntents,
            request_deserializer=google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.BatchDeleteIntentsRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.dialogflow.v2.Intents", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class Intents(object):
    """Service for managing [Intents][google.cloud.dialogflow.v2.Intent].
    """

    @staticmethod
    def ListIntents(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Intents/ListIntents",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.ListIntentsRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.ListIntentsResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetIntent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Intents/GetIntent",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.GetIntentRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateIntent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Intents/CreateIntent",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.CreateIntentRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateIntent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Intents/UpdateIntent",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.UpdateIntentRequest.SerializeToString,
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.Intent.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteIntent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Intents/DeleteIntent",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.DeleteIntentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def BatchUpdateIntents(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Intents/BatchUpdateIntents",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.BatchUpdateIntentsRequest.SerializeToString,
            google_dot_longrunning_dot_operations__pb2.Operation.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def BatchDeleteIntents(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.dialogflow.v2.Intents/BatchDeleteIntents",
            google_dot_cloud_dot_dialogflow__v2_dot_proto_dot_intent__pb2.BatchDeleteIntentsRequest.SerializeToString,
            google_dot_longrunning_dot_operations__pb2.Operation.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
